/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'lt', {
	border: 'Rodyti rėmelį',
	noUrl: 'Nurodykite iframe nuorodą',
	scrolling: 'Įjungti slankiklius',
	title: 'IFrame nustatymai',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
